@@ -1,5 +1,4 @@
 import argparse
-import os
 
 from murfey.util.db import clear, setup
 
@@ -16,18 +15,8 @@ def run():
         action="store_false",
         help="Do not clear current database tables before creating specified tables",
     )
-    parser.add_argument(
-        "-m",
-        "--microscope",
-        dest="microscope",
-        type=str,
-        default="",
-        help="Microscope as specified in the Murfey machine configuration",
-    )
 
     args = parser.parse_args()
-    if args.microscope:
-        os.environ["BEAMLINE"] = args.microscope
 
     from murfey.server.murfey_db import url
 
