@@ -18,10 +18,11 @@ from sqlmodel import Session as MurfeySession
 from sqlmodel import create_engine, select
 
 from murfey.client.contexts.spa import _get_xml_list_index
-from murfey.server import _murfey_id, _register
-from murfey.server.ispyb import Session, TransportManager, get_session_id
+from murfey.server.feedback import _murfey_id, _register
+from murfey.server.ispyb import ISPyBSession, TransportManager, get_session_id
 from murfey.server.murfey_db import url
 from murfey.util import db
+from murfey.util.api import url_path_for
 from murfey.util.config import get_machine_config, get_microscope, get_security_config
 
 
@@ -69,7 +70,7 @@ def run():
         help="Path to directory containing image files",
     )
     parser.add_argument(
-        "--suffic",
+        "--suffix",
         dest="suffix",
         required=True,
         type=str,
@@ -203,7 +204,9 @@ def run():
         ]
     )
     binning_factor = 1
-    server_config = requests.get(f"{args.url}/machine").json()
+    server_config = requests.get(
+        f"{args.url}{url_path_for('session_control.router', 'machine_info_by_instrument', instrument_name=args.microscope)}"
+    ).json()
     if server_config.get("superres"):
         # If camera is capable of superres and collection is in superres
         binning_factor = 2
@@ -223,12 +226,12 @@ def run():
     metadata["image_size_y"] = str(int(metadata["image_size_y"]) * binning_factor)
     metadata["motion_corr_binning"] = 1 if binning_factor_xml == 2 else 2
     metadata["gain_ref"] = (
-        f"data/{datetime.now().year}/{args.visit}/processing/gain.mrc"
+        f"{datetime.now().year}/{args.visit}/processing/gain.mrc"
         if args.gain_ref is None
         else args.gain_ref
     )
     metadata["gain_ref_superres"] = (
-        f"data/{datetime.now().year}/{args.visit}/processing/gain_superres.mrc"
+        f"{datetime.now().year}/{args.visit}/processing/gain_superres.mrc"
         if args.gain_ref_superres is None
         else args.gain_ref_superres
     )
@@ -256,7 +259,7 @@ def run():
             proposal_code=args.visit[:2],
             proposal_number=args.visit[2:].split("-")[0],
             visit_number=args.visit.split("-")[1],
-            db=Session(),
+            db=ISPyBSession(),
         ),
     )
 
