@@ -26,10 +26,11 @@ logger = logging.getLogger("murfey.client.contexts.spa")
 
 
 def _file_transferred_to(
-    environment: MurfeyInstanceEnvironment, source: Path, file_path: Path
+    environment: MurfeyInstanceEnvironment, source: Path, file_path: Path, token: str
 ):
     machine_config = get_machine_config_client(
         str(environment.url.geturl()),
+        token,
         instrument_name=environment.instrument_name,
         demo=environment.demo,
     )
@@ -111,8 +112,8 @@ class SPAModularContext(Context):
         ProcessingParameter("motion_corr_binning", "Motion Correction Binning"),
     ]
 
-    def __init__(self, acquisition_software: str, basepath: Path):
-        super().__init__("SPA", acquisition_software)
+    def __init__(self, acquisition_software: str, basepath: Path, token: str):
+        super().__init__("SPA", acquisition_software, token)
         self._basepath = basepath
         self._processing_job_stash: dict = {}
         self._foil_holes: Dict[int, List[int]] = {}
@@ -229,6 +230,7 @@ class SPAModularContext(Context):
                 base_url=str(environment.url.geturl()),
                 router_name="session_control.router",
                 function_name="machine_info_by_instrument",
+                token=self._token,
                 instrument_name=environment.instrument_name,
             )
             if server_config_response is None:
@@ -302,6 +304,7 @@ class SPAModularContext(Context):
                     base_url=str(environment.url.geturl()),
                     router_name="session_info.router",
                     function_name="get_dc_groups",
+                    token=self._token,
                     session_id=environment.murfey_session,
                 )
                 .json()
@@ -339,7 +342,9 @@ class SPAModularContext(Context):
                 else metadata_source_as_str
             )
             image_path = (
-                _file_transferred_to(environment, metadata_source, Path(gs.image))
+                _file_transferred_to(
+                    environment, metadata_source, Path(gs.image), self._token
+                )
                 if gs.image
                 else ""
             )
@@ -347,6 +352,7 @@ class SPAModularContext(Context):
                 base_url=str(environment.url.geturl()),
                 router_name="session_control.spa_router",
                 function_name="register_grid_square",
+                token=self._token,
                 session_id=environment.murfey_session,
                 gsid=grid_square,
                 data={
@@ -385,7 +391,9 @@ class SPAModularContext(Context):
                     else metadata_source_as_str
                 )
                 image_path = (
-                    _file_transferred_to(environment, metadata_source, Path(fh.image))
+                    _file_transferred_to(
+                        environment, metadata_source, Path(fh.image), self._token
+                    )
                     if fh.image
                     else ""
                 )
@@ -393,6 +401,7 @@ class SPAModularContext(Context):
                     base_url=str(environment.url.geturl()),
                     router_name="session_control.spa_router",
                     function_name="register_foil_hole",
+                    token=self._token,
                     session_id=environment.murfey_session,
                     gs_name=grid_square,
                     data={
@@ -416,6 +425,7 @@ class SPAModularContext(Context):
                     base_url=str(environment.url.geturl()),
                     router_name="session_control.spa_router",
                     function_name="register_foil_hole",
+                    token=self._token,
                     session_id=environment.murfey_session,
                     gs_name=grid_square,
                     data={
@@ -444,6 +454,7 @@ class SPAModularContext(Context):
                     if environment:
                         machine_config = get_machine_config_client(
                             str(environment.url.geturl()),
+                            self._token,
                             instrument_name=environment.instrument_name,
                             demo=environment.demo,
                         )
@@ -470,13 +481,14 @@ class SPAModularContext(Context):
 
                     if environment:
                         file_transferred_to = _file_transferred_to(
-                            environment, source, transferred_file
+                            environment, source, transferred_file, self._token
                         )
                         if not environment.movie_counters.get(str(source)):
                             movie_counts_get = capture_get(
                                 base_url=str(environment.url.geturl()),
                                 router_name="session_control.router",
                                 function_name="count_number_of_movies",
+                                token=self._token,
                             )
                             if movie_counts_get is not None:
                                 environment.movie_counters[str(source)] = count(
@@ -493,6 +505,7 @@ class SPAModularContext(Context):
                                 base_url=str(environment.url.geturl()),
                                 router_name="file_io_instrument.router",
                                 function_name="write_eer_fractionation_file",
+                                token=self._token,
                                 visit_name=environment.visit,
                                 session_id=environment.murfey_session,
                                 data={
@@ -552,6 +565,7 @@ class SPAModularContext(Context):
                             base_url=str(environment.url.geturl()),
                             router_name="workflow.spa_router",
                             function_name="request_spa_preprocessing",
+                            token=self._token,
                             visit_name=environment.visit,
                             session_id=environment.murfey_session,
                             data={
