@@ -10,12 +10,13 @@ from typing import Literal, Optional, Type, Union
 
 from backports.entry_points_selectable import entry_points
 from fastapi import APIRouter
-from pydantic import BaseModel, validator
+from pydantic import BaseModel, field_validator
 from sqlalchemy.exc import NoResultFound
 from sqlmodel import Session, select
 
 from murfey.server import _transport_object
 from murfey.server.murfey_db import murfey_db
+from murfey.util import sanitise
 from murfey.util.config import get_machine_config
 from murfey.util.db import (
     CLEMImageMetadata,
@@ -30,7 +31,10 @@ from murfey.util.db import Session as MurfeySession
 logger = getLogger("murfey.server.api.clem")
 
 # Create APIRouter class object
-router = APIRouter()
+router = APIRouter(
+    prefix="/workflow/clem",
+    tags=["Workflows: CLEM"],
+)
 
 # Valid file types
 valid_file_types = (
@@ -77,7 +81,7 @@ def validate_and_sanitise(
     machine_config = get_machine_config(instrument_name=instrument_name)[
         instrument_name
     ]
-    base_path = machine_config.rsync_basepath.as_posix()
+    rsync_basepath = machine_config.rsync_basepath.resolve()
 
     # Check that full file path doesn't contain unallowed characters
     #   Currently allows only:
@@ -90,13 +94,9 @@ def validate_and_sanitise(
         raise ValueError(f"Unallowed characters present in {file}")
 
     # Check that it's not accessing somehwere it's not allowed
-    if not str(full_path).startswith(str(base_path)):
+    if not str(full_path).startswith(str(rsync_basepath)):
         raise ValueError(f"{file} points to a directory that is not permitted")
 
-    # Check that it's a file, not a directory
-    if full_path.is_file() is False:
-        raise ValueError(f"{file} is not a file")
-
     # Check that it is of a permitted file type
     if f"{full_path.suffix}" not in valid_file_types:
         raise ValueError(f"{full_path.suffix} is not a permitted file format")
@@ -184,7 +184,7 @@ def get_db_entry(
         )
         db.add(db_entry)
         db.commit()
-        db.refresh(db_entry)
+
     except Exception:
         raise Exception
 
@@ -196,14 +196,25 @@ API ENDPOINTS FOR FILE REGISTRATION
 """
 
 
+class LifInfo(BaseModel):
+    lif_file: Path
+    master_metadata: Optional[Path] = None
+    child_metadata: list[Path] = []
+    child_series: list[str] = []
+    child_stacks: list[Path] = []
+
+
+class TiffInfo(BaseModel):
+    tiff_file: Path
+    associated_metadata: Optional[Path] = None
+    associated_series: Optional[str] = None
+    associated_stack: Optional[Path] = None
+
+
 @router.post("/sessions/{session_id}/clem/lif_files")
 def register_lif_file(
-    lif_file: Path,
+    lif_file: LifInfo,
     session_id: int,
-    master_metadata: Optional[Path] = None,
-    child_metadata: list[Path] = [],
-    child_series: list[str] = [],
-    child_stacks: list[Path] = [],
     db: Session = murfey_db,
 ):
     # Return or register the LIF file entry
@@ -212,22 +223,32 @@ def register_lif_file(
             db=db,
             table=CLEMLIFFile,
             session_id=session_id,
-            file_path=lif_file,
+            file_path=lif_file.lif_file,
         )
     except Exception:
-        logger.error(traceback.format_exc())
+        logger.error(
+            "Exception encountered while registering "
+            f"LIF file {sanitise(str(lif_file))!r}: \n"
+            f"{traceback.format_exc()}"
+        )
         return False
 
     # Add metadata information if provided
-    if master_metadata is not None:
+    if lif_file.master_metadata is not None:
         try:
-            master_metadata = validate_and_sanitise(master_metadata, session_id, db)
+            master_metadata = validate_and_sanitise(
+                lif_file.master_metadata, session_id, db
+            )
             clem_lif_file.master_metadata = str(master_metadata)
         except Exception:
-            logger.warning(traceback.format_exc())
+            logger.warning(
+                "Unable to add master metadata information to database entry for "
+                f"LIF file {sanitise(str(lif_file))!r}: \n"
+                f"{traceback.format_exc()}"
+            )
 
     # Register child metadata if provided
-    for metadata in child_metadata:
+    for metadata in lif_file.child_metadata:
         try:
             metadata_db_entry: CLEMImageMetadata = get_db_entry(
                 db=db,
@@ -238,11 +259,16 @@ def register_lif_file(
             # Append to database entry
             clem_lif_file.child_metadata.append(metadata_db_entry)
         except Exception:
-            logger.warning(traceback.format_exc())
+            logger.warning(
+                "Unable to register "
+                f"metadata file {sanitise(str(metadata))!r} in association with "
+                f"LIF file {sanitise(str(lif_file))!r}: \n"
+                f"{traceback.format_exc()}"
+            )
             continue
 
     # Register child image series if provided
-    for series in child_series:
+    for series in lif_file.child_series:
         try:
             series_db_entry: CLEMImageSeries = get_db_entry(
                 db=db,
@@ -253,11 +279,16 @@ def register_lif_file(
             # Append to database entry
             clem_lif_file.child_series.append(series_db_entry)
         except Exception:
-            logger.warning(traceback.format_exc())
+            logger.warning(
+                "Unable to register "
+                f"metadata file {sanitise(series)!r} in association with "
+                f"LIF file {sanitise(str(lif_file))!r}: \n"
+                f"{traceback.format_exc()}"
+            )
             continue
 
     # Register child image stacks if provided
-    for stack in child_stacks:
+    for stack in lif_file.child_stacks:
         try:
             stack_db_entry: CLEMImageStack = get_db_entry(
                 db=db,
@@ -268,7 +299,12 @@ def register_lif_file(
             # Append to database entry
             clem_lif_file.child_stacks.append(stack_db_entry)
         except Exception:
-            logger.warning(traceback.format_exc())
+            logger.warning(
+                "Unable to register "
+                f"image stack {sanitise(str(stack))!r} in association with "
+                f"LIF file {sanitise(str(lif_file))!r}: \n"
+                f"{traceback.format_exc()}"
+            )
             continue
 
     # Commit to database
@@ -280,11 +316,8 @@ def register_lif_file(
 
 @router.post("/sessions/{session_id}/clem/tiff_files")
 def register_tiff_file(
-    tiff_file: Path,
+    tiff_file: TiffInfo,
     session_id: int,
-    associated_metadata: Optional[Path] = None,
-    associated_series: Optional[str] = None,
-    associated_stack: Optional[Path] = None,
     db: Session = murfey_db,
 ):
     # Get or register the database entry
@@ -293,53 +326,71 @@ def register_tiff_file(
             db=db,
             table=CLEMTIFFFile,
             session_id=session_id,
-            file_path=tiff_file,
+            file_path=tiff_file.tiff_file,
         )
     except Exception:
-        logger.error(traceback.format_exc())
+        logger.error(
+            "Exception encountered while registering "
+            f"TIFF file {sanitise(str(tiff_file))!r}: \n"
+            f"{traceback.format_exc()}"
+        )
         return False
 
     # Add metadata if provided
-    if associated_metadata is not None:
+    if tiff_file.associated_metadata is not None:
         try:
             metadata_db_entry: CLEMImageMetadata = get_db_entry(
                 db=db,
                 table=CLEMImageMetadata,
                 session_id=session_id,
-                file_path=associated_metadata,
+                file_path=tiff_file.associated_metadata,
             )
             # Link database entries
             clem_tiff_file.associated_metadata = metadata_db_entry
         except Exception:
-            logger.warning(traceback.format_exc())
+            logger.warning(
+                "Unable to register "
+                f"metadata file {sanitise(str(tiff_file.associated_metadata))!r} in association with "
+                f"TIFF file {sanitise(str(tiff_file))!r}: \n"
+                f"{traceback.format_exc()}"
+            )
 
     # Add series information if provided
-    if associated_series is not None:
+    if tiff_file.associated_series is not None:
         try:
             series_db_entry: CLEMImageSeries = get_db_entry(
                 db=db,
                 table=CLEMImageSeries,
                 session_id=session_id,
-                series_name=associated_series,
+                series_name=tiff_file.associated_series,
             )
             # Link database entries
             clem_tiff_file.child_series = series_db_entry
         except Exception:
-            logger.warning(traceback.format_exc())
+            logger.warning(
+                "Unable to register "
+                f"CLEM series {sanitise(tiff_file.associated_series)!r} in association with "
+                f"TIFF file {sanitise(str(tiff_file))!r}: \n"
+                f"{traceback.format_exc()}"
+            )
 
     # Add image stack information if provided
-    if associated_stack is not None:
+    if tiff_file.associated_stack is not None:
         try:
             stack_db_entry: CLEMImageStack = get_db_entry(
                 db=db,
                 table=CLEMImageStack,
                 session_id=session_id,
-                file_path=associated_stack,
+                file_path=tiff_file.associated_stack,
             )
             # Link database entries
             clem_tiff_file.child_stack = stack_db_entry
         except Exception:
-            logger.warning(traceback.format_exc())
+            logger.warning(
+                "Unable to register "
+                f"image stack {sanitise(str(tiff_file.associated_stack))!r} in association with "
+                f"{traceback.format_exc()}"
+            )
 
     # Commit to database
     db.add(clem_tiff_file)
@@ -368,7 +419,11 @@ def register_clem_metadata(
             file_path=metadata_file,
         )
     except Exception:
-        logger.error(traceback.format_exc())
+        logger.error(
+            "Exception encountered while registering"
+            f"metadata file {sanitise(str(metadata_file))!r}"
+            f"{traceback.format_exc()}"
+        )
         return False
 
     # Register a parent LIF file if provided
@@ -383,7 +438,12 @@ def register_clem_metadata(
             # Link database entries
             clem_metadata.parent_lif = lif_db_entry
         except Exception:
-            logger.warning(traceback.format_exc())
+            logger.warning(
+                "Unable to register "
+                f"LIF file {sanitise(str(parent_lif))!r} in association with "
+                f"metadata file {sanitise(str(metadata_file))!r}: \n"
+                f"{traceback.format_exc()}"
+            )
 
     # Register associated TIFF files if provided
     for tiff in associated_tiffs:
@@ -397,7 +457,12 @@ def register_clem_metadata(
             # Append entry
             clem_metadata.associated_tiffs.append(tiff_db_entry)
         except Exception:
-            logger.warning(traceback.format_exc())
+            logger.warning(
+                "Unable to register "
+                f"TIFF file {sanitise(str(tiff))!r} in association with "
+                f"metadata file {sanitise(str(metadata_file))!r}: \n"
+                f"{traceback.format_exc()}"
+            )
             continue
 
     # Register associated image series if provided
@@ -414,7 +479,12 @@ def register_clem_metadata(
             db.add(series_db_entry)
             db.commit()
         except Exception:
-            logger.warning(traceback.format_exc())
+            logger.warning(
+                "Unable to register "
+                f"CLEM series {sanitise(associated_series)!r} in association with "
+                f"metadata file {sanitise(str(metadata_file))!r}: \n"
+                f"{traceback.format_exc()}"
+            )
 
     # Register associated image stacks if provided
     for stack in associated_stacks:
@@ -427,7 +497,12 @@ def register_clem_metadata(
             )
             clem_metadata.associated_stacks.append(stack_db_entry)
         except Exception:
-            logger.warning(traceback.format_exc())
+            logger.warning(
+                "Unable to register "
+                f"image stack {sanitise(str(stack))!r} in association with "
+                f"metadata file {sanitise(str(metadata_file))!r}: \n"
+                f"{traceback.format_exc()}"
+            )
             continue
 
     # Commit to database
@@ -456,7 +531,11 @@ def register_image_series(
             series_name=series_name,
         )
     except Exception:
-        logger.error(traceback.format_exc())
+        logger.error(
+            "Exception encountered while registering "
+            f"CLEM series {sanitise(series_name)!r}: \n"
+            f"{traceback.format_exc()}"
+        )
         return False
 
     # Register parent LIF file if provided
@@ -471,7 +550,12 @@ def register_image_series(
             # Link entries
             clem_image_series.parent_lif = lif_db_entry
         except Exception:
-            logger.warning(traceback.format_exc())
+            logger.warning(
+                "Unable to register "
+                f"LIF file {sanitise(str(parent_lif))!r} in association with "
+                f"CLEM series {sanitise(series_name)!r}: \n"
+                f"{traceback.format_exc()}"
+            )
 
     # Register parent TIFFs if provided
     for tiff in parent_tiffs:
@@ -485,7 +569,12 @@ def register_image_series(
             # Append entry
             clem_image_series.parent_tiffs.append(tiff_db_entry)
         except Exception:
-            logger.warning(traceback.format_exc())
+            logger.warning(
+                "Unable to register "
+                f"TIFF file {sanitise(str(tiff))!r} in association with "
+                f"CLEM series {sanitise(series_name)!r}: \n"
+                f"{traceback.format_exc()}"
+            )
             continue  # Try next item in loop
 
     # Register associated metadata if provided
@@ -500,7 +589,12 @@ def register_image_series(
             # Link entries
             clem_image_series.associated_metadata = metadata_db_entry
         except Exception:
-            logger.warning(traceback.format_exc())
+            logger.warning(
+                "Unable to register "
+                f"metadata file {sanitise(str(associated_metadata))!r} in association with "
+                f"CLEM series {sanitise(series_name)!r}: \n"
+                f"{traceback.format_exc()}"
+            )
 
     # Register child image stacks if provided
     for stack in child_stacks:
@@ -514,7 +608,12 @@ def register_image_series(
             # Append entry
             clem_image_series.child_stacks.append(stack_db_entry)
         except Exception:
-            logger.warning(traceback.format_exc())
+            logger.warning(
+                "Unable to register "
+                f"image stack {sanitise(str(stack))!r} in association with "
+                f"CLEM series {sanitise(series_name)!r}: \n"
+                f"{traceback.format_exc()}"
+            )
             continue
 
     # Register
@@ -544,7 +643,11 @@ def register_image_stack(
             file_path=image_stack,
         )
     except Exception:
-        logger.error(traceback.format_exc())
+        logger.error(
+            "Exception encountered while registering "
+            f"image stack {sanitise(str(image_stack))!r}: \n"
+            f"{traceback.format_exc()}"
+        )
         return False
 
     # Register channel name if provided
@@ -562,7 +665,12 @@ def register_image_stack(
             )
             clem_image_stack.parent_lif = lif_db_entry
         except Exception:
-            logger.warning(traceback.format_exc())
+            logger.warning(
+                "Unable to register "
+                f"LIF file {sanitise(str(parent_lif))!r} in association with "
+                f"image stack {sanitise(str(image_stack))!r}: \n"
+                f"{traceback.format_exc()}"
+            )
 
     # Register parent TIFF files if provided
     for tiff in parent_tiffs:
@@ -576,7 +684,12 @@ def register_image_stack(
             # Append entry
             clem_image_stack.parent_tiffs.append(tiff_db_entry)
         except Exception:
-            logger.warning(traceback.format_exc())
+            logger.warning(
+                "Unable to register "
+                f"TIFF file {sanitise(str(tiff))!r} in association with "
+                f"image stack {sanitise(str(image_stack))!r}: \n"
+                f"{traceback.format_exc()}"
+            )
             continue
 
     # Register associated metadata if provided
@@ -591,7 +704,12 @@ def register_image_stack(
             # Link entries
             clem_image_stack.associated_metadata = metadata_db_entry
         except Exception:
-            logger.warning(traceback.format_exc())
+            logger.warning(
+                "Unable to register "
+                f"metadata file {sanitise(str(associated_metadata))!r} in association with "
+                f"image stack {sanitise(str(image_stack))!r}: \n"
+                f"{traceback.format_exc()}"
+            )
 
     # Register parent series if provided
     if parent_series is not None:
@@ -605,7 +723,12 @@ def register_image_stack(
             # Link entries
             clem_image_stack.parent_series = series_db_entry
         except Exception:
-            logger.warning(traceback.format_exc())
+            logger.warning(
+                "Unable to register "
+                f"CLEM series {sanitise(parent_series)!r} in association with "
+                f"image stack {sanitise(str(image_stack))!r}: \n"
+                f"{traceback.format_exc()}"
+            )
 
     # Register updates to entry
     db.add(clem_image_stack)
@@ -624,7 +747,7 @@ API ENDPOINTS FOR FILE PROCESSING
 )  # API posts to this URL
 def process_raw_lifs(
     session_id: int,
-    lif_file: Path,
+    lif_file: LifInfo,
     db: Session = murfey_db,
 ):
     try:
@@ -646,7 +769,7 @@ def process_raw_lifs(
     # Pass arguments along to the correct workflow
     workflow.load()(
         # Match the arguments found in murfey.workflows.clem.process_raw_lifs
-        file=lif_file,
+        file=lif_file.lif_file,
         root_folder="images",
         session_id=session_id,
         instrument_name=instrument_name,
@@ -707,10 +830,8 @@ class AlignAndMergeParams(BaseModel):
     flatten: Literal["mean", "min", "max", ""] = ""
     align_across: Literal["enabled", ""] = ""
 
-    @validator(
-        "images",
-        pre=True,
-    )
+    @field_validator("images", mode="before")
+    @classmethod
     def parse_stringified_list(cls, value):
         if isinstance(value, str):
             try:
