@@ -2,13 +2,9 @@ from __future__ import annotations
 
 import datetime
 import logging
-import os
-from typing import Callable, List, Literal, Optional
+from typing import Callable, Generator, List, Literal, Optional
 
 import ispyb
-
-# import ispyb.sqlalchemy
-import sqlalchemy.orm
 import workflows.transport
 from fastapi import Depends
 from ispyb.sqlalchemy import (
@@ -30,17 +26,54 @@ from ispyb.sqlalchemy import (
     ZcZocaloBuffer,
     url,
 )
+from pydantic import BaseModel
+from sqlalchemy import create_engine
+from sqlalchemy.orm import Session, sessionmaker
 
-from murfey.util.models import FoilHoleParameters, GridSquareParameters, Sample, Visit
+from murfey.util import sanitise
+from murfey.util.config import get_security_config
+from murfey.util.models import (
+    FoilHoleParameters,
+    GridSquareParameters,
+    SearchMapParameters,
+)
 
 log = logging.getLogger("murfey.server.ispyb")
+security_config = get_security_config()
 
 try:
-    Session = sqlalchemy.orm.sessionmaker(
-        bind=sqlalchemy.create_engine(url(), connect_args={"use_pure": True})
+    ISPyBSession = sessionmaker(
+        bind=create_engine(
+            url(credentials=security_config.ispyb_credentials),
+            connect_args={"use_pure": True},
+        )
     )
-except AttributeError:
-    Session = lambda: None
+    log.info("Loaded ISPyB database session")
+# Catch all errors associated with loading ISPyB database
+except Exception:
+    log.error("Error loading ISPyB session", exc_info=True)
+    ISPyBSession = lambda: None
+
+
+class Visit(BaseModel):
+    start: datetime.datetime
+    end: datetime.datetime
+    session_id: int
+    name: str
+    beamline: str
+    proposal_title: str
+
+    def __repr__(self) -> str:
+        return (
+            "Visit("
+            f"start='{self.start:%Y-%m-%d %H:%M}', "
+            f"end='{self.end:%Y-%m-%d %H:%M}', "
+            f"session_id='{self.session_id!r}',"
+            f"name={self.name!r}, "
+            f"beamline={self.beamline!r}, "
+            f"proposal_title={self.proposal_title!r}"
+            ")"
+        )
 
 
 def _send_using_new_connection(transport_type: str, queue: str, message: dict) -> None:
@@ -60,7 +93,17 @@ class TransportManager:
         self.transport = workflows.transport.lookup(transport_type)()
         self.transport.connect()
         self.feedback_queue = ""
-        self.ispyb = ispyb.open() if os.getenv("ISPYB_CREDENTIALS") else None
+        try:
+            # Attempt to connect to ISPyB if credentials files provided
+            self.ispyb = (
+                ispyb.open(credentials=security_config.ispyb_credentials)
+                if security_config.ispyb_credentials
+                else None
+            )
+        except Exception:
+            # Log error and return None if the connection fails
+            log.error("Error encountered connecting to ISPyB server", exc_info=True)
+            self.ispyb = None
         self._connection_callback: Callable | None = None
 
     def reconnect(self):
@@ -81,7 +124,7 @@ class TransportManager:
         **kwargs,
     ):
         try:
-            with Session() as db:
+            with ISPyBSession() as db:
                 db.add(record)
                 db.commit()
                 log.info(f"Created DataCollectionGroup {record.dataCollectionGroupId}")
@@ -96,7 +139,7 @@ class TransportManager:
 
     def do_insert_atlas(self, record: Atlas):
         try:
-            with Session() as db:
+            with ISPyBSession() as db:
                 db.add(record)
                 db.commit()
                 log.info(f"Created Atlas {record.atlasId}")
@@ -113,11 +156,11 @@ class TransportManager:
         self, atlas_id: int, atlas_image: str, pixel_size: float, slot: int
     ):
         try:
-            with Session() as db:
+            with ISPyBSession() as db:
                 atlas = db.query(Atlas).filter(Atlas.atlasId == atlas_id).one()
-                atlas.atlasImage = atlas_image
-                atlas.pixelSize = pixel_size
-                atlas.cassetteSlot = slot
+                atlas.atlasImage = atlas_image or atlas.atlasImage
+                atlas.pixelSize = pixel_size or atlas.pixelSize
+                atlas.cassetteSlot = slot or atlas.cassetteSlot
                 db.add(atlas)
                 db.commit()
                 return {"success": True, "return_value": atlas.atlasId}
@@ -181,7 +224,7 @@ class TransportManager:
             pixelSize=grid_square_parameters.pixel_size,
         )
         try:
-            with Session() as db:
+            with ISPyBSession() as db:
                 db.add(record)
                 db.commit()
                 log.info(f"Created GridSquare {record.gridSquareId}")
@@ -198,7 +241,7 @@ class TransportManager:
         self, grid_square_id: int, grid_square_parameters: GridSquareParameters
     ):
         try:
-            with Session() as db:
+            with ISPyBSession() as db:
                 grid_square = (
                     db.query(GridSquare)
                     .filter(GridSquare.gridSquareId == grid_square_id)
@@ -213,32 +256,28 @@ class TransportManager:
                         grid_square_parameters.readout_area_x
                         / grid_square_parameters.thumbnail_size_x
                     )
-                grid_square.gridSquareImage = grid_square_parameters.image
-                grid_square.pixelLocationX = (
-                    int(grid_square_parameters.x_location / 7.8)
-                    if grid_square_parameters.x_location
-                    else None
-                )
-                grid_square.pixelLocationY = (
-                    int(grid_square_parameters.y_location / 7.8)
-                    if grid_square_parameters.y_location
-                    else None
-                )
-                grid_square.pixelLocationY = grid_square_parameters.y_location
-                grid_square.height = (
-                    int(grid_square_parameters.height / 7.8)
-                    if grid_square_parameters.height is not None
-                    else None
-                )
-                grid_square.width = (
-                    int(grid_square_parameters.width / 7.8)
-                    if grid_square_parameters.width is not None
-                    else None
-                )
-                grid_square.angle = grid_square_parameters.angle
-                grid_square.stageLocationX = grid_square_parameters.x_stage_position
-                grid_square.stageLocationY = grid_square_parameters.y_stage_position
-                grid_square.pixelSize = grid_square_parameters.pixel_size
+                if grid_square_parameters.image:
+                    grid_square.gridSquareImage = grid_square_parameters.image
+                if grid_square_parameters.x_location:
+                    grid_square.pixelLocationX = int(
+                        grid_square_parameters.x_location / 7.8
+                    )
+                if grid_square_parameters.y_location:
+                    grid_square.pixelLocationY = int(
+                        grid_square_parameters.y_location / 7.8
+                    )
+                if grid_square_parameters.height is not None:
+                    grid_square.height = int(grid_square_parameters.height / 7.8)
+                if grid_square_parameters.width is not None:
+                    grid_square.width = int(grid_square_parameters.width / 7.8)
+                if grid_square_parameters.angle:
+                    grid_square.angle = grid_square_parameters.angle
+                if grid_square_parameters.x_stage_position:
+                    grid_square.stageLocationX = grid_square_parameters.x_stage_position
+                if grid_square_parameters.y_stage_position:
+                    grid_square.stageLocationY = grid_square_parameters.y_stage_position
+                if grid_square_parameters.pixel_size:
+                    grid_square.pixelSize = grid_square_parameters.pixel_size
                 db.add(grid_square)
                 db.commit()
                 return {"success": True, "return_value": grid_square.gridSquareId}
@@ -253,7 +292,7 @@ class TransportManager:
     def do_insert_foil_hole(
         self,
         grid_square_id: int,
-        scale_factor: float,
+        scale_factor: Optional[float],
         foil_hole_parameters: FoilHoleParameters,
     ):
         if (
@@ -265,21 +304,22 @@ class TransportManager:
                 foil_hole_parameters.readout_area_x
                 / foil_hole_parameters.thumbnail_size_x
             )
-        foil_hole_parameters.diameter = (
-            int(foil_hole_parameters.diameter * scale_factor)
-            if foil_hole_parameters.diameter
-            else None
-        )
-        foil_hole_parameters.x_location = (
-            int(foil_hole_parameters.x_location * scale_factor)
-            if foil_hole_parameters.x_location
-            else None
-        )
-        foil_hole_parameters.y_location = (
-            int(foil_hole_parameters.y_location * scale_factor)
-            if foil_hole_parameters.y_location
-            else None
-        )
+        if scale_factor:
+            foil_hole_parameters.diameter = (
+                int(foil_hole_parameters.diameter * scale_factor)
+                if foil_hole_parameters.diameter
+                else None
+            )
+            foil_hole_parameters.x_location = (
+                int(foil_hole_parameters.x_location * scale_factor)
+                if foil_hole_parameters.x_location
+                else None
+            )
+            foil_hole_parameters.y_location = (
+                int(foil_hole_parameters.y_location * scale_factor)
+                if foil_hole_parameters.y_location
+                else None
+            )
         record = FoilHole(
             gridSquareId=grid_square_id,
             foilHoleLabel=foil_hole_parameters.name,
@@ -292,10 +332,10 @@ class TransportManager:
             pixelSize=foil_hole_parameters.pixel_size,
         )
         try:
-            with Session() as db:
+            with ISPyBSession() as db:
                 db.add(record)
                 db.commit()
-                log.info(f"Created FoilHole {record.gridSquareId}")
+                log.info(f"Created FoilHole {record.foilHoleId}")
                 return {"success": True, "return_value": record.foilHoleId}
         except ispyb.ISPyBException as e:
             log.error(
@@ -312,28 +352,26 @@ class TransportManager:
         foil_hole_parameters: FoilHoleParameters,
     ):
         try:
-            with Session() as db:
+            with ISPyBSession() as db:
                 foil_hole = (
                     db.query(FoilHole).filter(FoilHole.foilHoleId == foil_hole_id).one()
                 )
-                foil_hole.foilHoleImage = foil_hole_parameters.image
-                foil_hole.pixelLocationX = (
-                    int(foil_hole_parameters.x_location * scale_factor)
-                    if foil_hole_parameters.x_location
-                    else None
-                )
-                foil_hole.pixelLocationY = (
-                    int(foil_hole_parameters.y_location * scale_factor)
-                    if foil_hole_parameters.y_location
-                    else None
-                )
-                foil_hole.diameter = (
-                    foil_hole_parameters.diameter * scale_factor
-                    if foil_hole_parameters.diameter is not None
-                    else None
-                )
-                foil_hole.stageLocationX = foil_hole_parameters.x_stage_position
-                foil_hole.stageLocationY = foil_hole_parameters.y_stage_position
+                if foil_hole_parameters.image:
+                    foil_hole.foilHoleImage = foil_hole_parameters.image
+                if foil_hole_parameters.x_location:
+                    foil_hole.pixelLocationX = int(
+                        foil_hole_parameters.x_location * scale_factor
+                    )
+                if foil_hole_parameters.y_location:
+                    foil_hole.pixelLocationY = int(
+                        foil_hole_parameters.y_location * scale_factor
+                    )
+                if foil_hole_parameters.diameter is not None:
+                    foil_hole.diameter = foil_hole_parameters.diameter * scale_factor
+                if foil_hole_parameters.x_stage_position:
+                    foil_hole.stageLocationX = foil_hole_parameters.x_stage_position
+                if foil_hole_parameters.y_stage_position:
+                    foil_hole.stageLocationY = foil_hole_parameters.y_stage_position
                 if (
                     foil_hole_parameters.readout_area_x is not None
                     and foil_hole_parameters.thumbnail_size_x is not None
@@ -354,6 +392,117 @@ class TransportManager:
             )
         return {"success": False, "return_value": None}
 
+    def do_insert_search_map(
+        self,
+        atlas_id: int,
+        search_map_parameters: SearchMapParameters,
+    ):
+        if (
+            search_map_parameters.pixel_size
+            and search_map_parameters.height
+            and search_map_parameters.height_on_atlas
+        ):
+            search_map_parameters.pixel_size *= (
+                search_map_parameters.height / search_map_parameters.height_on_atlas
+            )
+        search_map_parameters.height = (
+            int(search_map_parameters.height / 7.8)
+            if search_map_parameters.height
+            else None
+        )
+        search_map_parameters.width = (
+            int(search_map_parameters.width / 7.8)
+            if search_map_parameters.width
+            else None
+        )
+        search_map_parameters.x_location = (
+            int(search_map_parameters.x_location / 7.8)
+            if search_map_parameters.x_location
+            else None
+        )
+        search_map_parameters.y_location = (
+            int(search_map_parameters.y_location / 7.8)
+            if search_map_parameters.y_location
+            else None
+        )
+        record = GridSquare(
+            atlasId=atlas_id,
+            gridSquareImage=search_map_parameters.image,
+            pixelLocationX=search_map_parameters.x_location,
+            pixelLocationY=search_map_parameters.y_location,
+            height=search_map_parameters.height_on_atlas,
+            width=search_map_parameters.width_on_atlas,
+            angle=0,
+            stageLocationX=search_map_parameters.x_stage_position,
+            stageLocationY=search_map_parameters.y_stage_position,
+            pixelSize=search_map_parameters.pixel_size,
+        )
+        try:
+            with ISPyBSession() as db:
+                db.add(record)
+                db.commit()
+                log.info(f"Created SearchMap (GridSquare) {record.gridSquareId}")
+                return {"success": True, "return_value": record.gridSquareId}
+        except ispyb.ISPyBException as e:
+            log.error(
+                "Inserting SearchMap (GridSquare) entry caused exception '%s'.",
+                e,
+                exc_info=True,
+            )
+        return {"success": False, "return_value": None}
+
+    def do_update_search_map(
+        self, search_map_id, search_map_parameters: SearchMapParameters
+    ):
+        try:
+            with ISPyBSession() as db:
+                grid_square = (
+                    db.query(GridSquare)
+                    .filter(GridSquare.gridSquareId == search_map_id)
+                    .one()
+                )
+                if (
+                    search_map_parameters.pixel_size
+                    and search_map_parameters.height
+                    and search_map_parameters.height_on_atlas
+                ):
+                    search_map_parameters.pixel_size *= (
+                        search_map_parameters.height
+                        / search_map_parameters.height_on_atlas
+                    )
+                if search_map_parameters.image:
+                    grid_square.gridSquareImage = search_map_parameters.image
+                if search_map_parameters.x_location:
+                    grid_square.pixelLocationX = int(
+                        search_map_parameters.x_location / 7.8
+                    )
+                if search_map_parameters.y_location:
+                    grid_square.pixelLocationY = int(
+                        search_map_parameters.y_location / 7.8
+                    )
+                if search_map_parameters.height_on_atlas:
+                    grid_square.height = int(
+                        search_map_parameters.height_on_atlas / 7.8
+                    )
+                if search_map_parameters.width_on_atlas:
+                    grid_square.width = int(search_map_parameters.width_on_atlas / 7.8)
+                if search_map_parameters.x_stage_position:
+                    grid_square.stageLocationX = search_map_parameters.x_stage_position
+                if search_map_parameters.y_stage_position:
+                    grid_square.stageLocationY = search_map_parameters.y_stage_position
+                if search_map_parameters.pixel_size:
+                    grid_square.pixelSize = search_map_parameters.pixel_size
+                db.add(grid_square)
+                db.commit()
+                return {"success": True, "return_value": grid_square.gridSquareId}
+        except ispyb.ISPyBException as e:
+            log.error(
+                "Updating SearchMap (GridSquare) entry caused exception '%s'.",
+                e,
+                exc_info=True,
+            )
+        return {"success": False, "return_value": None}
+
     def send(self, queue: str, message: dict, new_connection: bool = False):
         if self.transport:
             if not self.transport.is_connected():
@@ -372,7 +521,7 @@ class TransportManager:
             else "Created for Murfey"
         )
         try:
-            with Session() as db:
+            with ISPyBSession() as db:
                 record.comments = comment
                 db.add(record)
                 db.commit()
@@ -388,7 +537,7 @@ class TransportManager:
 
     def do_insert_sample_group(self, record: BLSampleGroup) -> dict:
         try:
-            with Session() as db:
+            with ISPyBSession() as db:
                 db.add(record)
                 db.commit()
                 log.info(f"Created BLSampleGroup {record.blSampleGroupId}")
@@ -403,7 +552,7 @@ class TransportManager:
 
     def do_insert_sample(self, record: BLSample, sample_group_id: int) -> dict:
         try:
-            with Session() as db:
+            with ISPyBSession() as db:
                 db.add(record)
                 db.commit()
                 log.info(f"Created BLSample {record.blSampleId}")
@@ -426,7 +575,7 @@ class TransportManager:
 
     def do_insert_subsample(self, record: BLSubSample) -> dict:
         try:
-            with Session() as db:
+            with ISPyBSession() as db:
                 db.add(record)
                 db.commit()
                 log.info(f"Created BLSubSample {record.blSubSampleId}")
@@ -441,7 +590,7 @@ class TransportManager:
 
     def do_insert_sample_image(self, record: BLSampleImage) -> dict:
         try:
-            with Session() as db:
+            with ISPyBSession() as db:
                 db.add(record)
                 db.commit()
                 log.info(f"Created BLSampleImage {record.blSampleImageId}")
@@ -524,7 +673,7 @@ class TransportManager:
             return {"success": False, "return_value": None}
 
     def do_buffer_lookup(self, app_id: int, uuid: int) -> Optional[int]:
-        with Session() as db:
+        with ISPyBSession() as db:
             buffer_objects = (
                 db.query(ZcZocaloBuffer)
                 .filter_by(AutoProcProgramID=app_id, UUID=uuid)
@@ -535,8 +684,8 @@ class TransportManager:
         return reference
 
 
-def _get_session() -> sqlalchemy.orm.Session:
-    db = Session()
+def _get_session() -> Generator[Optional[Session], None, None]:
+    db = ISPyBSession()
     if db is None:
         yield None
         return
@@ -546,8 +695,8 @@ def _get_session() -> sqlalchemy.orm.Session:
         db.close()
 
 
-DB = Depends(_get_session)
 # Shortcut to access the database in a FastAPI endpoint
+DB = Depends(_get_session)
 
 
 def get_session_id(
@@ -555,8 +704,19 @@ def get_session_id(
     proposal_code: str,
     proposal_number: str,
     visit_number: str,
-    db: sqlalchemy.orm.Session | None,
+    db: Session | None,
 ) -> int | None:
+
+    # Log received lookup parameters
+    log.debug(
+        "Looking up ISPyB BLSession ID using the following values:\n"
+        f"microscope: {sanitise(microscope)}\n"
+        f"proposal_code: {sanitise(proposal_code)}\n"
+        f"proposal_number: {sanitise(str(proposal_number))}\n"
+        f"visit_number: {sanitise(str(visit_number))}\n"
+    )
+
+    # Lookup BLSession ID
     if db is None:
         return None
     query = (
@@ -577,9 +737,7 @@ def get_session_id(
     return res
 
 
-def get_proposal_id(
-    proposal_code: str, proposal_number: str, db: sqlalchemy.orm.Session
-) -> int:
+def get_proposal_id(proposal_code: str, proposal_number: str, db: Session) -> int:
     query = (
         db.query(Proposal)
         .filter(
@@ -591,35 +749,9 @@ def get_proposal_id(
     return query[0].proposalId
 
 
-def get_sub_samples_from_visit(visit: str, db: sqlalchemy.orm.Session) -> List[Sample]:
-    proposal_id = get_proposal_id(visit[:2], visit.split("-")[0][2:], db)
-    samples = (
-        db.query(BLSampleGroup, BLSampleGroupHasBLSample, BLSample, BLSubSample)
-        .join(BLSample, BLSample.blSampleId == BLSampleGroupHasBLSample.blSampleId)
-        .join(
-            BLSampleGroup,
-            BLSampleGroup.blSampleGroupId == BLSampleGroupHasBLSample.blSampleGroupId,
-        )
-        .join(BLSubSample, BLSubSample.blSampleId == BLSample.blSampleId)
-        .filter(BLSampleGroup.proposalId == proposal_id)
-        .all()
-    )
-    res = [
-        Sample(
-            sample_group_id=s[1].blSampleGroupId,
-            sample_id=s[2].blSampleId,
-            subsample_id=s[3].blSubSampleId,
-            image_path=s[3].imgFilePath,
-        )
-        for s in samples
-    ]
-    return res
-
-
-def get_all_ongoing_visits(
-    microscope: str, db: sqlalchemy.orm.Session | None
-) -> list[Visit]:
+def get_all_ongoing_visits(microscope: str, db: Session | None) -> list[Visit]:
     if db is None:
+        print("No database found")
         return []
     query = (
         db.query(BLSession)
@@ -652,16 +784,3 @@ def get_all_ongoing_visits(
         )
         for row in query
     ]
-
-
-def get_data_collection_group_ids(session_id):
-    query = (
-        Session()
-        .query(DataCollectionGroup)
-        .filter(
-            DataCollectionGroup.sessionId == session_id,
-        )
-        .all()
-    )
-    dcgids = [row.dataCollectionGroupId for row in query]
-    return dcgids
